@@ -17,18 +17,20 @@ class _PackagerFiles:
         """ Generate setup.py and overwrite local repo.
 
             :param generalpackager.Packager self: """
+        last_version_split = self.python[-1].split(".")
+        last_version_bumped_micro = f"{last_version_split[0]}.{int(last_version_split[1]) + 1}"
         setup_kwargs = {
             "name": f'"{self.localrepo.name}"',
             "author": f"'{self.author}'",
             "author_email": f'"{self.email}"',
             "version": f'"{self.localrepo.version}"',
             "description": f'"{self.localrepo.description}"',
-            "long_description": f"Path(r'{self.localrepo.get_readme_path()}').read_text(encoding='utf-8')",
+            "long_description": f"Path(r'{self.localrepo.get_readme_path().relative()}').read_text(encoding='utf-8')",
             "long_description_content_type": '"text/markdown"',
             "install_requires": self.localrepo.install_requires,
             "url": f'"{self.github.url()}"',
             "license": f'"{self.license}"',
-            "python_requires": f'"{", ".join([f"=={ver}.*" for ver in self.python])}"',
+            "python_requires": f'">={self.python[0]}, <{last_version_bumped_micro}"',
             "packages": 'find_namespace_packages(exclude=("build*", "dist*"))',
             "extras_require": self.localrepo.extras_require,
             "classifiers": self.get_classifiers(),
@@ -69,3 +71,18 @@ class _PackagerFiles:
         assert "$" not in text
 
         self.generate_file(self.localrepo.get_license_path(), text)
+
+    def generate_workflow(self):
+        """ Generate workflow.yml.
+
+            :param generalpackager.Packager self: """
+        workflow = CodeLine()
+        workflow.indent_str = " " * 2
+
+        workflow.add("name: workflow")
+        workflow.add(self.get_triggers())
+
+        jobs = workflow.add("jobs:")
+        jobs.add(self.get_unittest_job())
+
+        self.localrepo.get_workflow_path().text.write(workflow.text(), overwrite=True)
