@@ -8,5 +8,5 @@ class _PackagerGitHub:
             :param generalpackager.Packager self: """
         self.github.set_website(self.pypi.url)
         self.github.set_description(self.localrepo.description)
-        self.github.set_topics(self.get_topics())
+        self.github.set_topics(*self.get_topics())
 
